#!/sbin/sh
#
# Initialize/Shutdown TANGO Interactive Server v. 1.4 
#
# Copyright WebWisdom.com LLC 1999. All rights reserved
#


stat_server() {
  ps -ef | grep wisdom | grep $PORT  > /dev/null
  exitcode=$?
  if [ $exitcode -eq 0 ]; then
    return 0
  else
    return 1
  fi
}


OS=IRIX
IS_ON=/sbin/chkconfig
VERSNAME=WebWisdom/tango-server-unix
TIVERS_=tango14_
TANGOOWNER=tango
TANGOHOME=/usr/people/$TANGOOWNER/$VERSNAME
TANGOLOG=$TANGOHOME/logs
PORT=11000

case "$1" in
'start')
  stat_server
  ec=$?
  if [ $ec -eq 0 ]; then
    echo "Server on port $PORT already running - aborting"
    exit 1
  fi
  if [ -f $TANGOHOME/exec/$OS-tango_start ]; then
    if $IS_ON $TIVERS_$PORT ; then
      if $IS_ON verbose ; then
        echo "Starting TANGO Interactive Server\n"
      fi
      /bin/su $TANGOOWNER -c "cd $TANGOHOME/exec; ./$OS-tango_start $PORT"
    fi
  fi
;;

'stop')
  if [ -f $TANGOLOG/pid_$PORT ]; then
    echo "Stopping TANGO Interactive Server on port $PORT\n"
    PID=`cat $TANGOLOG/pid_$PORT`
    stat_server
    ec=$?
    if [ $ec -eq 0 ]; then
      /bin/kill -15 $PID
    else
      echo "Process not found. Cleaning up PID file."
    fi
    /bin/rm -f  $TANGOLOG/pid_$PORT
    echo "Done.\n"
  else
    stat_server
    ec=$?
    if [ $ec -eq 0 ]; then
      echo "PID file of a running server was manually deleted. Kill server process yourself and keep clowns away.\n"
    else
      echo "Nothing to stop or clean.\n"
    fi
  fi
;;

'stat')
  stat_server
  ec=$?
  if [ $ec -eq 0 ]; then 
    if [ -f $TANGOLOG/pid_$PORT ]; then
      PID=`cat $TANGOLOG/pid_$PORT`
      echo "TANGO Interactive Server on port $PORT is running, process id: $PID\n"
    else
      echo "TANGO Interactive Server on port $PORT is running, but it has no PID file.\n"
    fi
  else
    if [ -f $TANGOLOG/pid_$PORT ]; then
      echo "TANGO Interactive Server on port $PORT is not running. Cleaning up PID file."
      /bin/rm -f  $TANGOLOG/pid_$PORT
    else
      echo "TANGO Interactive Server on port $PORT is not running."
    fi
  fi
;;

*)
    echo "usage: $0 {start|stop|stat}"
    ;;
esac

